@@ -193,9 +193,8 @@ class LineFormatterTest extends MonologTestCase
         });
 
         $message = $formatter->format($this->getRecord(Level::Critical, context: ['exception' => new \RuntimeException('Foo')]));
-        $trace = explode('[stacktrace]', $message, 2)[1];
-        $this->assertStringNotContainsString('#', $trace);
-        $this->assertSame(PHP_EOL . PHP_EOL . '"} []' . PHP_EOL, $trace);
+        $this->assertStringNotContainsString('[stacktrace]', $message);
+        $this->assertStringEndsWith('"} []' . PHP_EOL, $message);
     }
 
     public function testDefFormatWithPreviousException()
