@@ -11,10 +11,9 @@
 
 namespace Monolog\Handler;
 
-use Monolog\Test\TestCase;
 use Monolog\Level;
 
-class DoctrineCouchDBHandlerTest extends TestCase
+class DoctrineCouchDBHandlerTest extends \Monolog\Test\MonologTestCase
 {
     protected function setUp(): void
     {
