@@ -12,9 +12,8 @@
 namespace Monolog\Handler;
 
 use Monolog\Level;
-use Monolog\Test\TestCase;
 
-class FilterHandlerTest extends TestCase
+class FilterHandlerTest extends \Monolog\Test\MonologTestCase
 {
     /**
      * @covers Monolog\Handler\FilterHandler::isHandling
