@@ -67,7 +67,7 @@ class StreamHandlerTest extends \Monolog\Test\MonologTestCase
 
     /**
      * @covers Monolog\Handler\StreamHandler::close
-     * @covers Monolog\Handler\Handler::__sleep
+     * @covers Monolog\Handler\Handler::__serialize
      */
     public function testSerialization()
     {
@@ -365,4 +365,16 @@ The exception occurred while attempting to log: test');
             ini_set('memory_limit', $previousValue);
         }
     }
+
+    public function testReopensFileIfInodeChanges()
+    {
+        $filename = __DIR__ . '/test.log';
+        $handler = new StreamHandler($filename);
+        $handler->setFormatter($this->getIdentityFormatter());
+        $handler->handle($this->getRecord(Level::Warning, 'test1'));
+        @unlink($filename);
+        $handler->handle($this->getRecord(Level::Warning, 'test2'));
+        $data = @file_get_contents($filename);
+        $this->assertEquals('test2', $data);
+    }
 }
