@@ -12,12 +12,11 @@
 namespace Monolog\Handler;
 
 use Monolog\Logger;
-use Monolog\Test\TestCase;
 use PHPUnit\Framework\MockObject\MockObject;
 use Symfony\Component\Mailer\MailerInterface;
 use Symfony\Component\Mime\Email;
 
-class SymfonyMailerHandlerTest extends TestCase
+class SymfonyMailerHandlerTest extends \Monolog\Test\MonologTestCase
 {
     /** @var MailerInterface&MockObject */
     private $mailer;
