@@ -12,9 +12,8 @@
 namespace Monolog\Processor;
 
 use Monolog\Level;
-use Monolog\Test\TestCase;
 
-class GitProcessorTest extends TestCase
+class GitProcessorTest extends \Monolog\Test\MonologTestCase
 {
     /**
      * @covers Monolog\Processor\GitProcessor::__invoke
