@@ -11,9 +11,7 @@
 
 namespace Monolog\Processor;
 
-use Monolog\Test\TestCase;
-
-class WebProcessorTest extends TestCase
+class WebProcessorTest extends \Monolog\Test\MonologTestCase
 {
     public function testProcessor()
     {
